==> xfxwidgets-1.8.43.tar.gz: lib/XActionsBase.dart <==
import 'package:flutter/material.dart';
import 'package:xfxbase/XfxToolTips.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'XF_MAIN/XAppState.dart';

class XActionsBase {
  // static XAction get item_DELETE => XAction("DEL", 0, "Elimina", background_Color: Colors.red, icon: Icons.delete, label_Color: Colors.white);
  XActionsBase();

  static XAction _item_DELETE = XAction("DEL", 0, "Elimina", background_Color: Colors.red, icon: Icons.delete, label_Color: Colors.white);
  static XAction get item_DELETE => _item_DELETE;
  static set item_DELETE(XAction newValue) => _item_DELETE = newValue;

  static XAction _save = XAction("save", 800, "", icon: Icons.done, icon_Color: Colors.green, toolTip: "Salva la Scheda e continua a modificare.");
  static XAction get save => _save;
  static set save(XAction newValue) => _save = newValue;

  static XAction _showXMedia = XAction("BTN_ViewXMedia", 900, "", toolTip: XfxToolTips.BTN_ShowXMedia);
  static XAction get showXMedia => _showXMedia;
  static set showXMedia(XAction newValue) => _showXMedia = newValue;

  static XAction _addXMedia = XAction("BTN_AddXMedia", 901, "", toolTip: XfxToolTips.BTN_GetXMedia, icon: Icons.photo_camera_outlined, icon_Color: Colors.orange);
  static XAction get addXMedia => _addXMedia;
  static set addXMedia(XAction newValue) => _addXMedia = newValue;

  static XAction _addDett = XAction("BTN_Add", 902, "", icon: Icons.add, toolTip: XfxToolTips.BTN_AddDett, icon_Color: XColors.done);
  static XAction get addDett => _addDett;
  static set addDett(XAction newValue) => _addDett = newValue;

  static XAction _popUpActions = XAction("BTN_PopUpActions", 903, "");
  static XAction get popUpActions => _popUpActions;
  static set popUpActions(XAction newValue) => _popUpActions = newValue;
}
  // XAction("BTN_AddXMedia", 901, ""),
  //     XAction("BTN_Add", 902, ""),
  //     XAction("BTN_PopUpActions", 903, ""),

==> xfxwidgets-1.9.79.tar.gz: lib/XActionsBase.dart <==
import 'package:flutter/material.dart';
import 'package:xfxbase/XfxToolTips.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'XF_MAIN/XAppState.dart';

class XActionsBase {
  // static XAction get item_DELETE => XAction("DEL", 0, "Elimina", background_Color: Colors.red, icon: Icons.delete, label_Color: Colors.white);
  XActionsBase();

  static XAction _item_DELETE = XAction("DEL", 0, "", background_Color: Colors.red, icon: Icons.delete, label_Color: Colors.white);
  static XAction get item_DELETE => _item_DELETE;
  static set item_DELETE(XAction newValue) => _item_DELETE = newValue;

  static XAction _save = XAction("save", 800, "", icon: Icons.done, icon_Color: Colors.green, toolTip: "Salva la Scheda e continua a modificare.");
  static XAction get save => _save;
  static set save(XAction newValue) => _save = newValue;

  static XAction _showXMedia = XAction("BTN_ViewXMedia", 900, "", toolTip: XfxToolTips.BTN_ShowXMedia, icon_Color: Colors.amber);
  static XAction get showXMedia => _showXMedia;
  static set showXMedia(XAction newValue) => _showXMedia = newValue;

  static XAction _addXMedia = XAction("BTN_AddXMedia", 901, "", toolTip: XfxToolTips.BTN_GetXMedia, icon: Icons.photo_camera_outlined, icon_Color: Colors.orange);
  static XAction get addXMedia => _addXMedia;
  static set addXMedia(XAction newValue) => _addXMedia = newValue;

  static XAction _addDett = XAction("BTN_Add", 902, "", icon: Icons.add, toolTip: XfxToolTips.BTN_AddDett, icon_Color: XColors.done);
  static XAction get addDett => _addDett;
  static set addDett(XAction newValue) => _addDett = newValue;

  static XAction _popUpActions = XAction("BTN_PopUpActions", 903, "");
  static XAction get popUpActions => _popUpActions;
  static set popUpActions(XAction newValue) => _popUpActions = newValue;
}
  // XAction("BTN_AddXMedia", 901, ""),
  //     XAction("BTN_Add", 902, ""),
  //     XAction("BTN_PopUpActions", 903, ""),
